@@ -261,6 +261,11 @@ class SchedulerBackend:
         select_cols = ListedOrigin.select_columns()
         insert_cols, insert_meta = ListedOrigin.insert_columns_and_metavars()
 
+        deduplicated_origins = {
+            tuple(getattr(origin, k) for k in pk_cols): origin
+            for origin in listed_origins
+        }
+
         upsert_cols = [col for col in insert_cols if col not in pk_cols]
         upsert_set = ", ".join(f"{col} = EXCLUDED.{col}" for col in upsert_cols)
 
@@ -274,7 +279,7 @@ class SchedulerBackend:
         ret = psycopg2.extras.execute_values(
             cur=cur,
             sql=query,
-            argslist=(attr.asdict(origin) for origin in listed_origins),
+            argslist=(attr.asdict(origin) for origin in deduplicated_origins.values()),
             template=f"({', '.join(insert_meta)})",
             page_size=1000,
             fetch=True,
@@ -378,31 +383,28 @@ class SchedulerBackend:
             where_clauses.append(
                 """origin_visit_stats.last_scheduled IS NULL
                 OR origin_visit_stats.last_scheduled < GREATEST(
-                  %s - %s,
+                  %s,
                   origin_visit_stats.last_visit
                 )
             """
             )
-            query_args.append(timestamp)
-            query_args.append(scheduled_cooldown)
+            query_args.append(timestamp - scheduled_cooldown)
 
         if failed_cooldown:
             # Don't retry failed origins too often
             where_clauses.append(
                 "origin_visit_stats.last_visit_status is distinct from 'failed' "
-                "or origin_visit_stats.last_visit < %s - %s"
+                "or origin_visit_stats.last_visit < %s"
             )
-            query_args.append(timestamp)
-            query_args.append(failed_cooldown)
+            query_args.append(timestamp - failed_cooldown)
 
         if not_found_cooldown:
             # Don't retry not found origins too often
             where_clauses.append(
                 "origin_visit_stats.last_visit_status is distinct from 'not_found' "
-                "or origin_visit_stats.last_visit < %s - %s"
+                "or origin_visit_stats.last_visit < %s"
             )
-            query_args.append(timestamp)
-            query_args.append(not_found_cooldown)
+            query_args.append(timestamp - not_found_cooldown)
 
         if policy == "oldest_scheduled_first":
             order_by = "origin_visit_stats.last_scheduled NULLS FIRST"
@@ -450,7 +452,7 @@ class SchedulerBackend:
                 INSERT INTO
                   visit_scheduler_queue_position(visit_type, position)
                 SELECT
-                  visit_type, COALESCE(MAX(next_visit_queue_position), now())
+                  visit_type, COALESCE(MAX(next_visit_queue_position), 0)
                 FROM selected_origins
                 GROUP BY visit_type
                 ON CONFLICT(visit_type) DO UPDATE
@@ -490,6 +492,15 @@ class SchedulerBackend:
 
         query_args.append(count)
 
+        # fmt: off
+        common_table_expressions.append(("deduplicated_selected_origins", """
+          SELECT DISTINCT
+            url, visit_type
+          FROM
+            selected_origins
+        """))
+        # fmt: on
+
         # fmt: off
         common_table_expressions.append(("update_stats", """
             INSERT INTO
@@ -497,7 +508,7 @@ class SchedulerBackend:
             SELECT
               url, visit_type, %s
             FROM
-              selected_origins
+              deduplicated_selected_origins
             ON CONFLICT (url, visit_type) DO UPDATE
               SET last_scheduled = GREATEST(
                 origin_visit_stats.last_scheduled,
@@ -1027,15 +1038,13 @@ class SchedulerBackend:
         return [OriginVisitStats(**row) for row in rows]
 
     @db_transaction()
-    def visit_scheduler_queue_position_get(
-        self, db=None, cur=None,
-    ) -> Dict[str, datetime.datetime]:
+    def visit_scheduler_queue_position_get(self, db=None, cur=None) -> Dict[str, int]:
         cur.execute("SELECT visit_type, position FROM visit_scheduler_queue_position")
         return {row["visit_type"]: row["position"] for row in cur}
 
     @db_transaction()
     def visit_scheduler_queue_position_set(
-        self, visit_type: str, position: datetime.datetime, db=None, cur=None,
+        self, visit_type: str, position: int, db=None, cur=None,
     ) -> None:
         query = """
             INSERT INTO visit_scheduler_queue_position(visit_type, position)
