@@ -3,9 +3,19 @@
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
+"""This is the first scheduler runner. It is in charge of scheduling "oneshot" tasks
+(e.g save code now, indexer, vault, deposit, ...). To do this, it reads tasks ouf of the
+scheduler backend and pushes those to their associated rabbitmq queues.
+
+The scheduler listener :mod:`swh.scheduler.celery_backend.pika_listener` is the module
+in charge of finalizing the task results.
+
+"""
+
 import logging
 from typing import Dict, List, Tuple
 
+from deprecated import deprecated
 from kombu.utils.uuid import uuid
 
 from swh.core.statsd import statsd
@@ -151,6 +161,7 @@ def run_ready_tasks(
         all_backend_tasks.extend(backend_tasks)
 
 
+@deprecated(version="0.18", reason="Use `swh scheduler start-runner` instead")
 def main():
     from .config import app as main_app
 
