@@ -8,8 +8,7 @@ from __future__ import annotations
 # WARNING: do not import unnecessary things here to keep cli startup time under
 # control
 import locale
-import logging
-from typing import TYPE_CHECKING, Any, Dict, Iterator, List, Optional
+from typing import TYPE_CHECKING, Iterator, List, Optional
 
 import click
 
@@ -589,166 +588,3 @@ def respawn_tasks(ctx, task_ids: List[str], next_run: datetime.datetime):
     output.append("Respawn tasks %s\n" % (task_ids_int,))
 
     click.echo("\n".join(output))
-
-
-@task.command("archive")
-@click.option(
-    "--before",
-    "-b",
-    default=None,
-    help="""Task whose ended date is anterior will be archived.
-                      Default to current month's first day.""",
-)
-@click.option(
-    "--after",
-    "-a",
-    default=None,
-    help="""Task whose ended date is after the specified date will
-                      be archived. Default to prior month's first day.""",
-)
-@click.option(
-    "--batch-index",
-    default=1000,
-    type=click.INT,
-    help="Batch size of tasks to read from db to archive",
-)
-@click.option(
-    "--bulk-index",
-    default=200,
-    type=click.INT,
-    help="Batch size of tasks to bulk index",
-)
-@click.option(
-    "--batch-clean",
-    default=1000,
-    type=click.INT,
-    help="Batch size of task to clean after archival",
-)
-@click.option(
-    "--dry-run/--no-dry-run",
-    is_flag=True,
-    default=False,
-    help="Default to list only what would be archived.",
-)
-@click.option("--verbose", is_flag=True, default=False, help="Verbose mode")
-@click.option(
-    "--cleanup/--no-cleanup",
-    is_flag=True,
-    default=True,
-    help="Clean up archived tasks (default)",
-)
-@click.option(
-    "--start-from",
-    type=click.STRING,
-    default=None,
-    help="(Optional) default page to start from.",
-)
-@click.pass_context
-def archive_tasks(
-    ctx,
-    before,
-    after,
-    batch_index,
-    bulk_index,
-    batch_clean,
-    dry_run,
-    verbose,
-    cleanup,
-    start_from,
-):
-    """Archive task/task_run whose (task_type is 'oneshot' and task_status
-       is 'completed') or (task_type is 'recurring' and task_status is
-       'disabled').
-
-       With --dry-run flag set (default), only list those.
-
-    """
-    from itertools import groupby
-
-    from swh.core.utils import grouper
-    from swh.scheduler.backend_es import ElasticSearchBackend
-    from swh.scheduler.utils import utcnow
-
-    config = ctx.obj["config"]
-    scheduler = ctx.obj["scheduler"]
-
-    if not scheduler:
-        raise ValueError("Scheduler class (local/remote) must be instantiated")
-
-    logging.basicConfig(level=logging.DEBUG if verbose else logging.INFO)
-    logger = logging.getLogger(__name__)
-    logging.getLogger("urllib3").setLevel(logging.WARN)
-    logging.getLogger("elasticsearch").setLevel(logging.ERROR)
-    if dry_run:
-        logger.info("**DRY-RUN** (only reading db)")
-    if not cleanup:
-        logger.info("**NO CLEANUP**")
-
-    es_storage = ElasticSearchBackend(**config)
-    now = utcnow()
-
-    # Default to archive tasks from a rolling month starting the week
-    # prior to the current one
-    if not before:
-        before = now.shift(weeks=-1).format("YYYY-MM-DD")
-
-    if not after:
-        after = now.shift(weeks=-1).shift(months=-1).format("YYYY-MM-DD")
-
-    logger.debug(
-        "index: %s; cleanup: %s; period: [%s ; %s]"
-        % (not dry_run, not dry_run and cleanup, after, before)
-    )
-
-    def get_index_name(
-        data: Dict[str, Any], es_storage: ElasticSearchBackend = es_storage
-    ) -> str:
-        """Given a data record, determine the index's name through its ending
-           date. This varies greatly depending on the task_run's
-           status.
-
-        """
-        date = data.get("started")
-        if not date:
-            date = data["scheduled"]
-        return es_storage.compute_index_name(date.year, date.month)
-
-    def index_data(before, page_token, batch_index):
-        while True:
-            result = scheduler.filter_task_to_archive(
-                after, before, page_token=page_token, limit=batch_index
-            )
-            tasks_sorted = sorted(result["tasks"], key=get_index_name)
-            groups = groupby(tasks_sorted, key=get_index_name)
-            for index_name, tasks_group in groups:
-                logger.debug("Index tasks to %s" % index_name)
-                if dry_run:
-                    for task in tasks_group:
-                        yield task
-                    continue
-
-                yield from es_storage.streaming_bulk(
-                    index_name,
-                    tasks_group,
-                    source=["task_id", "task_run_id"],
-                    chunk_size=bulk_index,
-                )
-
-            page_token = result.get("next_page_token")
-            if page_token is None:
-                break
-
-    gen = index_data(before, page_token=start_from, batch_index=batch_index)
-    if cleanup:
-        for task_ids in grouper(gen, n=batch_clean):
-            task_ids = list(task_ids)
-            logger.info("Clean up %s tasks: [%s, ...]" % (len(task_ids), task_ids[0]))
-            if dry_run:  # no clean up
-                continue
-            ctx.obj["scheduler"].delete_archived_tasks(task_ids)
-    else:
-        for task_ids in grouper(gen, n=batch_index):
-            task_ids = list(task_ids)
-            logger.info("Indexed %s tasks: [%s, ...]" % (len(task_ids), task_ids[0]))
-
-    logger.debug("Done!")
