@@ -11,6 +11,9 @@ create index on task_run(backend_id);
 
 create index task_run_id_asc_idx on task_run(task asc, started asc);
 
+create index on task(type, next_run)
+where status = 'next_run_not_scheduled'::task_status;
+
 
 -- lister schema
 create unique index on listers (name, instance_name);
