@@ -686,6 +686,15 @@ class TestScheduler:
 
         assert all(origin.first_seen == origin.last_seen for origin in ret)
 
+    def test_record_listed_origins_with_duplicate(self, swh_scheduler, listed_origins):
+        # the duplicates must be in the same page to raise the "on conflict error"
+        listed_origins.insert(0, listed_origins[0])
+
+        ret = swh_scheduler.record_listed_origins(listed_origins)
+
+        # without the duplicate
+        assert len(ret) == len(listed_origins) - 1
+
     def test_record_listed_origins_upsert(self, swh_scheduler, listed_origins):
         # First, insert `cutoff` origins
         cutoff = 100
@@ -1067,8 +1076,8 @@ class TestScheduler:
         swh_scheduler.record_listed_origins(origins)
 
         # Initially, we have no global queue position
-        actual_state = swh_scheduler.visit_scheduler_queue_position_get()
-        assert actual_state == {}
+        current_state = swh_scheduler.visit_scheduler_queue_position_get()
+        assert current_state == {}
 
         # nor any visit statuses
         actual_visit_stats = swh_scheduler.origin_visit_stats_get(
@@ -1084,8 +1093,8 @@ class TestScheduler:
         assert len(next_visits) == len(origins)
 
         # Now the global state got updated
-        actual_state = swh_scheduler.visit_scheduler_queue_position_get()
-        assert actual_state[visit_type] is not None
+        current_state = swh_scheduler.visit_scheduler_queue_position_get()
+        assert current_state[visit_type] is not None
 
         actual_visit_stats = swh_scheduler.origin_visit_stats_get(
             (o.url, o.visit_type) for o in next_visits
@@ -1111,10 +1120,9 @@ class TestScheduler:
         swh_scheduler.record_listed_origins(origins)
 
         # Initially, we have no global queue position
-        actual_state = swh_scheduler.visit_scheduler_queue_position_get()
-        assert actual_state == {}
+        current_state = swh_scheduler.visit_scheduler_queue_position_get()
+        assert current_state == {}
 
-        date_now = utcnow()
         # Simulate some of those origins have associated visit stats (some with an
         # existing queue position and some without any)
         visit_stats = (
@@ -1124,8 +1132,7 @@ class TestScheduler:
                     visit_type=origin.visit_type,
                     last_successful=utcnow(),
                     last_visit=utcnow(),
-                    next_visit_queue_position=date_now
-                    + timedelta(days=random.uniform(-10, 1)),
+                    next_visit_queue_position=int(24 * 3600 * random.uniform(-10, 1)),
                 )
                 for origin in origins[:100]
             ]
@@ -1135,8 +1142,9 @@ class TestScheduler:
                     visit_type=origin.visit_type,
                     last_successful=utcnow(),
                     last_visit=utcnow(),
-                    next_visit_queue_position=date_now
-                    + timedelta(days=random.uniform(1, 10)),  # definitely > now()
+                    next_visit_queue_position=int(
+                        24 * 3600 * random.uniform(1, 10)
+                    ),  # definitely > 0
                 )
                 for origin in origins[100:150]
             ]
@@ -1164,8 +1172,8 @@ class TestScheduler:
         )
         assert len(actual_visit_stats) == len(origins)
 
-        actual_state = swh_scheduler.visit_scheduler_queue_position_get()
-        assert actual_state == {
+        current_state = swh_scheduler.visit_scheduler_queue_position_get()
+        assert current_state == {
             visit_type: max(
                 s.next_visit_queue_position
                 for s in actual_visit_stats
@@ -1179,6 +1187,37 @@ class TestScheduler:
         with pytest.raises(UnknownPolicy, match=unknown_policy):
             swh_scheduler.grab_next_visits("type", NUM_RESULTS, policy=unknown_policy)
 
+    def test_grab_next_visit_duplicates(self, swh_scheduler, listed_origins):
+        """Checks grab_next_visits does not crash when there are rows with
+        duplicated (origin_url, visit_type) in the database
+        """
+        lister2 = swh_scheduler.get_or_create_lister(**LISTERS[1])
+        assert lister2.id != listed_origins[0].lister_id
+
+        # Create two origins with the same url and visit_type, but different listers
+        # (and also differing value for last_update so they are returned in
+        # deterministic order)
+        origin1 = attr.evolve(
+            listed_origins[0], first_seen=utcnow(), last_seen=utcnow()
+        )
+        origin2 = attr.evolve(
+            origin1,
+            lister_id=lister2.id,
+            last_update=origin1.last_update + datetime.timedelta(seconds=10),
+        )
+
+        origins = [origin1, origin2]
+        recorded_origins = swh_scheduler.record_listed_origins(origins)
+
+        expected_origins = sorted(recorded_origins, key=lambda o: o.last_update)
+
+        self._check_grab_next_visit(
+            swh_scheduler,
+            visit_type=origin1.visit_type,
+            policy="never_visited_oldest_update_first",
+            expected=expected_origins,
+        )
+
     def _create_task_types(self, scheduler):
         for tt in TASK_TYPES.values():
             scheduler.create_task_type(tt)
@@ -1316,7 +1355,7 @@ class TestScheduler:
             if visit_type in visit_types:
                 continue
             visit_types.add(visit_type)
-            position = utcnow()
+            position = 42
             swh_scheduler.visit_scheduler_queue_position_set(visit_type, position)
             expected_result[visit_type] = position
 
